<?php

namespace Ems\Logic\ProcessamentoSolicitacao;

use Ems\Util\Utils;
use Util\{ DateUtil, NovoCodigo, Repositories };

use Teknisa\Model\Gestaopessoas\Entities\GpeTipotransfer;
use Teknisa\Model\Geral\Entities\Tipoestrutura;

class ProcessamentoSolicitacaoRemanejamentoLegal extends ProcessamentoSolicitacao {
    
    public function efetivar() {
        $itens = $this->getItensAssociativeArray();
        
        $nrorg            = Utils::getParamters()->getNrorg();
        $nrvinculom       = $this->getSolicitacao()->getNrvinculom();
        $dtcompetencia    = DateUtil::getDataDeString(Utils::getParamters()->getDtmescomptencDiaCorrente(),DateUtil::FORMATO_BRASILEIRO,true);
        $dsobssolicitacao = $this->getSolicitacao()->getDsobssolicitacao();
        $observacao       = $this->getObservacaoComProtocolo($dsobssolicitacao);
        
        $paramOrg = Utils::getEntityManager()->getRepository(Repositories::GPE_PARAMORG)->findOneBy(['nrorg' => $nrorg]);
        $nrtipoestrutlegal = !empty($paramOrg) ? $paramOrg->getNrtpestrutlegal() : null;

        // Transferência/Remanejamento
        $nrtipotransfer = $itens['NRTIPOTRANSFER']  ?? null;
        $nrtpmovtransfm = $itens['NRTPMOVTRANSFM']  ?? null;
        $nrmotivotransf = $itens['NRMOTIVOTRANSF']  ?? null;
        $nrestrutlegal  = $itens['NRESTRUTLEGAL']  ?? null;
        $nrestrutgeren  = $itens['NRESTRUTGEREN']  ?? null;
        $dtinimoviment  = isset($itens['DTINIMOVIMENT']) ? DateUtil::getDataDeString(substr($itens['DTINIMOVIMENT'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
        $dtfimmoviment  = isset($itens['DTFIMMOVIMENT']) ? DateUtil::getDataDeString(substr($itens['DTFIMMOVIMENT'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
    
        $estrutura_nova_legal = Utils::getEntityManager()->getRepository(Repositories::ESTRUTURAM)->findOneBy(array("nrorg"=> $nrorg,"nrestruturam" => $nrestrutlegal));

        $estrutura_nova_geren = false;
        if($nrestrutgeren) {
            $estrutura_nova_geren = Utils::getEntityManager()->getRepository(Repositories::ESTRUTURAM)->findOneBy(array("nrorg"=> $nrorg,"nrestruturam" => $nrestrutgeren));
        }

        $result = Utils::getEntityManager()->getRepository(Repositories::GPE_MOVIMENTACAO)->findOneBy(array("nrorg"=> $nrorg,"nrvinculom" => $nrvinculom,"dtinimoviment" => $dtinimoviment));

        // ESCALA
        $nrturno        = $itens['NRTURNO']             ??  null;
        $nrmotivoescala = $itens['NRMOTIVOESCALA']      ??  null;
        $nrescalatrabm  = $itens['NRESCALATRABM']       ??  null;
        $dtiniescala    = isset($itens['DTINIESCALA']) ? DateUtil::getDataDeString(substr($itens['DTINIESCALA'],0,10), DateUtil::FORMATO_BRASILEIRO, true) : null;
        $dtcompetenciaString  = Utils::getParamters()->getDtmescomptencDiaCorrente();


        $gpevinculoH        = ProcessamentoSolicitacaoUtil::retornaUltimoHistoricoVinculoCompetencia($nrorg, $nrvinculom, $dtcompetencia->format('d/m/Y'));
        $nrestruturalegal   = $gpevinculoH->getNrestrutlegal();
        $nrestruturageren   = $gpevinculoH->getNrestrutgeren();

        // Validações Estruruta

        if($nrestrutlegal == $nrestruturalegal || $nrestrutgeren == $nrestruturageren) {
            throw new \Exception("Este vínculo já está registrado nesta Estrutura.");
        }

        // Valida se o tipo de transferência é para uma estrutura de um tipo compatível.
        $this->verificaTipoTransferencia($nrtipotransfer, $estrutura_nova_legal->getNrtipoestrutura());

        if($result){
            $estrutura_historico = Utils::getEntityManager()->getRepository(Repositories::ESTRUTURAM)->findOneBy(array("nrorg"=> $nrorg,"nrestruturam" => $result->getNrestruturam()));

            if($estrutura_historico->getNrtipoestrutura() == $estrutura_nova_legal->getNrtipoestrutura()) {
                throw new \Exception("Já existe uma movimentação para este tipo de estrutura nesta data");
            }
        }
        if($nrtipotransfer == 1){
            if($estrutura_nova_legal->getNrtipoestrutura() != $nrtipoestrutlegal && $estrutura_nova_legal->getNrtipoestrutura() != 10) {
                throw new \Exception("A nova estrutura legal deve ser do mesmo tipo que a antiga.");
            }
        }
        else if($estrutura_nova_legal->getNrtipoestrutura() == $nrtipoestrutlegal) {
            throw new \Exception("A nova estrutura legal deve ser de tipo diferente que a antiga.");
        }
   
        if($dtcompetenciaString !== $itens['DTINIMOVIMENT'] && !DateUtil::comparaDatas($dtinimoviment, DateUtil::getDataDeString($dtcompetenciaString), DateUtil::DEPOIS)){
            throw new \Exception("A movimentação não pode ser retroativa");
        }

        // Validações Escala
        if($nrescalatrabm && $nrturno && $dtiniescala) {
            $resultEscala = Utils::getEntityManager()->getRepository(Repositories::GPE_ALTEESCALA)->findBy(array("nrorg"=> $nrorg,"nrvinculom" => $nrvinculom,"dtiniescala" => $dtiniescala));

            if($resultEscala) {
                throw new \Exception("Já existe uma alteração de escala para este vinculo nesta data");
            }
        }


        $vinc = ProcessamentoSolicitacaoUtil::retornaUltimoHistoricoVinculoCompetencia($nrorg, $nrvinculom, $dtcompetencia);
        // Cria a Movimentação Legal
        ProcessamentoSolicitacaoUtil::novaMovimentacao($nrorg, $nrvinculom, $estrutura_nova_legal->getNrtipoestrutura(), $nrestrutlegal, $nrmotivotransf, $nrtipotransfer, $nrtpmovtransfm, $dtfimmoviment, $dtinimoviment, $observacao);

        if($nrestrutgeren && $estrutura_nova_geren) {
            // Cria a Movimentação Gerencial
            $nrtipotransfergeren = '2';
            ProcessamentoSolicitacaoUtil::novaMovimentacao($nrorg, $nrvinculom, $estrutura_nova_geren->getNrtipoestrutura(), $nrestrutgeren, $nrmotivotransf, $nrtipotransfergeren, $nrtpmovtransfm, $dtfimmoviment, $dtinimoviment, $observacao);
        }

        $dtfimmovimentsaida = DateUtil::subtraiIntervalo($dtinimoviment, 1)->format('d/m/Y');
        $dtfimmovimentsaida = DateUtil::getDataDeString(substr($dtfimmovimentsaida,0,10), DateUtil::FORMATO_BRASILEIRO, true);

        $estrutura_anterior = Utils::getEntityManager()->getRepository(Repositories::ESTRUTURAM)->findOneBy(array("nrorg"=> $nrorg,"nrestruturam" => $vinc->getNrestrutlegal()));

        // Cria a Movimentação de saida
        ProcessamentoSolicitacaoUtil::novaMovimentacao($nrorg, $nrvinculom, $estrutura_anterior->getNrtipoestrutura(), $vinc->getNrestrutlegal(), $nrmotivotransf, $nrtipotransfer, "9", $dtfimmovimentsaida, $dtinimoviment, $observacao);
        
        if($vinc->getDtmescompetenc() == $dtcompetencia){
            $vinc->setDtultatu(DateUtil::getDataAtual());
            $vinc->setNrorgultatu(Utils::getParamters()->getNrorg());
            $vinc->setCdoperultatu(Utils::getParamters()->getCdoperador());
            $vinc->setNrestrutlegal($nrestrutlegal);

            if($nrestrutgeren) {
                $vinc->setNrestrutgeren($nrestrutgeren);
            }

            Utils::getEntityManager()->persist($vinc);
            Utils::getEntityManager()->flush();
        }
        else {
            $newnrestrutgeren = $nrestrutgeren ? $nrestrutgeren : $vinc->getNrestrutgeren();

            ProcessamentoSolicitacaoUtil::novoHistoricoVinculo($nrorg, $nrvinculom, $dtcompetencia, $vinc->getNrsitufuncm(), $vinc->getNrcargo(), $vinc->getNrescalatrabm(),
                $vinc->getIdcontribuisind(), $vinc->getNrdependir(), $vinc->getNrdependsfam(), $vinc->getDtbaseferias(), $vinc->getIdremuneracao(),
                $vinc->getIdtppagamento(), $nrestrutlegal, $newnrestrutgeren, $vinc->getNrtpmodalidsal(), $vinc->getIdmultvinc(),
                $vinc->getNrfuncao(), $vinc->getCdcontribindividual(), $vinc->getNrtpmovtransfm(), $vinc->getDtfimcontrdetermin(),
                $vinc->getNrestrutsind(), $vinc->getConfidencial()
            );
        }


        if($nrescalatrabm && $nrturno && $dtiniescala) {            
            ProcessamentoSolicitacaoUtil::atualizaAlteEscala(
                $nrorg,
                $nrvinculom,
                $nrescalatrabm,
                DateUtil::subtraiIntervalo($dtiniescala,1,DateUtil::DIA)->format(DateUtil::FORMATO_BRASILEIRO),
                DateUtil::getDataAtual(true)->format(DateUtil::FORMATO_BRASILEIRO),
                Utils::getParamters()->getCdoperador()
            );

            ProcessamentoSolicitacaoUtil::atualizaEscalaVinculoh(
                $nrorg,
                $nrvinculom,
                $nrescalatrabm,
                DateUtil::getDataAtual(true)->format(DateUtil::FORMATO_BRASILEIRO),
                Utils::getParamters()->getCdoperador()
            );
            
            $alteEscala = ProcessamentoSolicitacaoUtil::novoAlteEscala($nrorg, $nrvinculom, $nrturno, $nrmotivoescala, $nrescalatrabm, $dtiniescala, $observacao);
        }
        
    }

    public function verificaTipoTransferencia($nrtipotransfer, $nrtipoestrutura){
        try {
            $paramOrg = Utils::getEntityManager()->getRepository(Repositories::GPE_PARAMORG)->findOneBy(array('nrorg' => Utils::getParamters()->getNrorg()));
            if ($nrtipotransfer == GpeTipotransfer::TIPOTRANSFLEGAL) {
                if ($nrtipoestrutura != $paramOrg->getNrtpestrutlegal() && $nrtipoestrutura != Tipoestrutura::SINDICATO) {
                    throw new \Exception('Movimentaçao legal incompatível com o tipo de estrutura', 30);
                }
            } elseif ($nrtipotransfer == GpeTipotransfer::TIPOTRANSFGEREN) {
                if (($nrtipoestrutura == $paramOrg->getNrtpestrutlegal() && $paramOrg->getNrtpestrutlegal() != $paramOrg->getNrtpestrutgeren()) || $nrtipoestrutura == Tipoestrutura::SINDICATO) {
                    throw new \Exception('Movimentaçao gerencial incompatível com o tipo de estrutura', 30);
                }
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function rejeitar() {}
}