<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;
use Ems\Util\Utils;

class IndicadoresSegurancaTrabalhoRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    public function getTotalAcidentes(
         $row
    ) {

        $sql = <<<SQL
        SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH AS INDICADOR , COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

    $query = $this->connection->prepare($sql);
    $query->execute(
        array(
            'P_NRORG'       => 3260,//(int) $row['NRORG'],
            'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
            'P_NRTIPOESTRUTOMADOR' => null,
            'P_NRESTRUTLEGAL' => null,
            'P_NRESTRUTGEREN' => null,
            'P_NRESTRUTSIND' => null,
            'P_NRESTRUTTOMAD' => null,
            'P_NRTIPOESTRUTGEREN' => 6
        )
    );

    return $query->fetchAll();
    }

    public function getTotalAcidentesGerenOcup(
        $row
   ) {

       $sql = <<<SQL
       SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH AS INDICADOR , COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTGEREN
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

   $query = $this->connection->prepare($sql);
   $query->execute(
       array(
           'P_NRORG'       => 3260,//(int) $row['NRORG'],
           'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
           'P_NRTIPOESTRUTOMADOR' => null,
           'P_NRESTRUTLEGAL' => 11,
           'P_NRESTRUTGEREN' => null,
           'P_NRESTRUTSIND' => null,
           'P_NRESTRUTTOMAD' => null,
           'P_NRTIPOESTRUTGEREN' => 6
       )
   );

   return $query->fetchAll();
   }

   public function getTotalAcidentesOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT OH.NMOCUPACAOH AS OCUPACAO,
         COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  OH.NMOCUPACAOH
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 3260,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => 11,
       'P_NRESTRUTGEREN' => null,
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getTotalAcidentesPorGravidadeLegalOcupacao(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH || ' || Gravidade: ' || GR.NMGRAVIDADE AS INDICADOR, COUNT(1) AS QTD_ACIDENTES, GR.NMGRAVIDADE as GRAVIDADE
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_GRAVIDADE GR
    ON GR.NRORG = VI.NRORG
        AND GR.NRGRAVIDADE = OC.NRGRAVIDADE
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, GR.NMGRAVIDADE
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 3260,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => 11,
       'P_NRESTRUTGEREN' => null,
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getTotalAcidentesPorGravidadeGerenOcup(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH || ' || Gravidade: ' || GR.NMGRAVIDADE AS INDICADOR , COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_GRAVIDADE GR
    ON GR.NRORG = VI.NRORG
        AND GR.NRGRAVIDADE = OC.NRGRAVIDADE
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTGEREN
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, GR.NMGRAVIDADE
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 20,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => null,
       'P_NRESTRUTGEREN' => '191004496',
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getTotalAcidentesPorGravidadeOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT 'Gravidade: ' || GR.NMGRAVIDADE || ' || Ocupação: ' || OH.NMOCUPACAOH AS OCUPACAO, COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_GRAVIDADE GR
    ON GR.NRORG = VI.NRORG
        AND GR.NRGRAVIDADE = OC.NRGRAVIDADE
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  OH.NMOCUPACAOH, GR.NMGRAVIDADE
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 20,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => null,
       'P_NRESTRUTGEREN' => '191004496',
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}
public function getQuantidadeDiasAfastadosLegalOcup(
    $row
) {

   $sql = <<<SQL
  SELECT OH.NMOCUPACAOH AS INDICADOR, SUM(ASF.NRQTDIASITUFUNC) AS QTD_AFASTAMENTOS
FROM GPE_ALTESITUFUNC ASF
JOIN GPE_VINCULOM VM
    ON VM.NRORG = ASF.NRORG
        AND ASF.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
JOIN GPE_SITUFUNCM SF
    ON SF.NRSITUFUNCM = ASF.NRSITUFUNCM
JOIN GPE_SITUFUNCH SFH
    ON SFH.NRSITUFUNCM = SF.NRSITUFUNCM
        AND SFH.DTEFETIVA = 
    (SELECT MAX(DTEFETIVA)
    FROM GPE_SITUFUNCH
    WHERE GPE_SITUFUNCH.DTEFETIVA <= :P_DTMESCOMPETENC
            AND GPE_SITUFUNCH.NRSITUFUNCM = SFH.NRSITUFUNCM
            AND GPE_SITUFUNCH.NRORG = SFH.NRORG)
WHERE ASF.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
        AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (SFH.IDAFASTSITUFUNC = 'S' /*Situacao funcional que gere afastamento*/
        OR SF.NRSITUFUNCM IN (12, 100012, 15, 16, 100084, 3, 5, 11))/*Atestados médico e odontológico, Afastamentos 15 dias empregador*/
        AND SF.NRSITUFUNCM <> 13 /*Demitito eh parametrizado como gera afastamento mas nao gera o evento*/
GROUP BY  EM.NMESTRUTURAM , OH.NMOCUPACAOH
HAVING SUM(ASF.NRQTDIASITUFUNC) IS NOT NULL
ORDER BY QTD_AFASTAMENTOS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 3260,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => 11,
       'P_NRESTRUTGEREN' => null,
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getQuantidadeDiasAfastadosOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT OH.NMOCUPACAOH AS INDICADOR, SUM(ASF.NRQTDIASITUFUNC) AS QTD_AFASTAMENTOS
FROM GPE_ALTESITUFUNC ASF
JOIN GPE_VINCULOM VM
    ON VM.NRORG = ASF.NRORG
        AND ASF.NRVINCULOM = VM.NRVINCULOM
JOIN GPE_VINCULOH VH
    ON VM.NRORG = VH.NRORG
        AND VM.NRVINCULOM = VH.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
JOIN GPE_SITUFUNCM SF
    ON SF.NRSITUFUNCM = ASF.NRSITUFUNCM
JOIN GPE_SITUFUNCH SFH
    ON SFH.NRSITUFUNCM = SF.NRSITUFUNCM
        AND SFH.DTEFETIVA = 
    (SELECT MAX(DTEFETIVA)
    FROM GPE_SITUFUNCH
    WHERE GPE_SITUFUNCH.DTEFETIVA <= :P_DTMESCOMPETENC
            AND GPE_SITUFUNCH.NRSITUFUNCM = SFH.NRSITUFUNCM
            AND GPE_SITUFUNCH.NRORG = SFH.NRORG)
WHERE ASF.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
        AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (SFH.IDAFASTSITUFUNC = 'S' /*Situacao funcional que gere afastamento*/
        OR SF.NRSITUFUNCM IN (12, 100012, 15, 16, 100084, 3, 5, 11))/*Atestados médico e odontológico, Afastamentos 15 dias empregador*/
        AND SF.NRSITUFUNCM <> 13 /*Demitito eh parametrizado como gera afastamento mas nao gera o evento*/
GROUP BY  OH.NMOCUPACAOH
HAVING SUM(ASF.NRQTDIASITUFUNC) IS NOT NULL
ORDER BY QTD_AFASTAMENTOS DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 3260,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => 11,
       'P_NRESTRUTGEREN' => null,
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getTotalPartesDoCorpoAtingidasLegalOcup(
    $row
) {

   $sql = <<<SQL
   SELECT 'Estrutura: ' || EM.NMESTRUTURAM || ' || Ocupação: ' || OH.NMOCUPACAOH || ' || Parte Atingida: ' || PA.NMPARTEATINGIDA AS INDICADOR, COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_VITIMAPARTEATINGIDA VPA
    ON VPA.NRORG = VI.NRORG
        AND VPA.NROCORRENCIA = VI.NROCORRENCIA
        AND VPA.NRVITIMA = VI.NRVITIMA
JOIN SST_PARTEATINGIDA PA
    ON VPA.NRPARTEATINGIDA = PA.NRPARTEATINGIDA
        AND PA.NRORG = VPA.NRORG
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, PA.NMPARTEATINGIDA
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 20,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => null,
       'P_NRESTRUTGEREN' => '191004496',
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getTotalPartesDoCorpoAtingidasOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
   SELECT 'Ocupação: ' || OH.NMOCUPACAOH || ' || Parte Atingida: ' || PA.NMPARTEATINGIDA AS INDICADOR, COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
JOIN SST_VITIMAPARTEATINGIDA VPA
    ON VPA.NRORG = VI.NRORG
        AND VPA.NROCORRENCIA = VI.NROCORRENCIA
        AND VPA.NRVITIMA = VI.NRVITIMA
JOIN SST_PARTEATINGIDA PA
    ON VPA.NRPARTEATINGIDA = PA.NRPARTEATINGIDA
        AND PA.NRORG = VPA.NRORG
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC =
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  OH.NMOCUPACAOH, PA.NMPARTEATINGIDA
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 20,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => null,
       'P_NRESTRUTGEREN' => '191004496',
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getSituacaoGeradoraAcidenteLegalOcup(
    $row
) {

   $sql = <<<SQL
   SELECT 'Ocupação: ' || OH.NMOCUPACAOH || ' || Situação Geradora: ' || SG.DSSITUGERADORA AS INDICADOR, COUNT(1) AS QTD_ACIDENTES
FROM SST_VITIMA VI
JOIN SST_OCORRENCIA OC
    ON OC.NRORG = VI.NRORG
        AND OC.NROCORRENCIA = VI.NROCORRENCIA
LEFT JOIN SST_TIPOOCORRE TPO
    ON TPO.NRORG = OC.NRORG
        AND TPO.NRTIPOOCORRE = OC.NRTIPOOCORRE
LEFT JOIN SST_SITUGERADORA SG
    ON SG.NRSITUGERADORA = TPO.NRSITUGERADORA AND(SG.NRORG = TPO.NRORG
        OR SG.NRORG = 0)
JOIN GPE_PESSOA PE
    ON PE.NRORG = VI.NRORG
        AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
JOIN GPE_VINCULOM VM
    ON VM.NRORG = VI.NRORG
        AND VM.NRPESSOA = PE.NRPESSOA
JOIN GPE_VINCULOH VH
    ON VH.NRORG = VI.NRORG
        AND VH.NRVINCULOM = VM.NRVINCULOM
        AND VH.DTMESCOMPETENC = 
    (SELECT DTMESCOMPETENC
    FROM 
        (SELECT H1.DTMESCOMPETENC
        FROM GPE_VINCULOH H1
        WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                AND H1.NRORG = VM.NRORG
                AND H1.NRVINCULOM = VM.NRVINCULOM
        ORDER BY  H1.DTMESCOMPETENC DESC)
        WHERE ROWNUM = 1)
    LEFT JOIN GPE_ALTEOCUPACAO AO
    ON AO.NRORG = VM.NRORG
        AND AO.NRVINCULOM = VM.NRVINCULOM
        AND AO.DTINIOCUPACAO = 
    (SELECT MAX(DTINIOCUPACAO)
    FROM GPE_ALTEOCUPACAO
    WHERE NRORG = VM.NRORG
            AND NRVINCULOM = VM.NRVINCULOM
            AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
LEFT JOIN GPE_OCUPACAOH OH
    ON AO.NROCUPACAOM = OH.NROCUPACAOM
        AND OH.NRORG = AO.NRORG
        AND OH.DTMESCOMPETENC = 
    (SELECT MAX(OHH.DTMESCOMPETENC)
    FROM GPE_OCUPACAOH OHH
    WHERE OHH.NRORG = :P_NRORG
            AND OHH.NROCUPACAOM = OH.NROCUPACAOM
            AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
LEFT JOIN TIPOHIERARQORG TH
    ON (TH.NRORG = VM.NRORG
        OR TH.NRORG = 0)
        AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
        AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
LEFT JOIN HIERARQUIAORG HO
    ON HO.NRORG = VM.NRORG
        AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
        AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
        AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
        AND (HO.DTFIMVIGENCIA IS NULL
        OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
        AND HO.DTINIVIGENCIA = 
    (SELECT MAX(DTINIVIGENCIA)
    FROM HIERARQUIAORG HI
    WHERE HI.NRORG = HO.NRORG
            AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
            AND NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
            AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
            AND (HI.DTFIMVIGENCIA IS NULL
            OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
LEFT JOIN ESTRUTURAM EMSUP
    ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
        AND EMSUP.NRORG = HO.NRORG
LEFT JOIN ESTRUTURAM EM
    ON EM.NRESTRUTURAM = VH.NRESTRUTLEGAL
        AND EM.NRORG = VH.NRORG
WHERE VI.NRORG = :P_NRORG
        AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL
        OR :P_NRESTRUTLEGAL IS NULL)
        AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN
        OR :P_NRESTRUTGEREN IS NULL)
        AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND
        OR :P_NRESTRUTSIND IS NULL)
        AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD
        OR :P_NRESTRUTTOMAD IS NULL)
        AND (VM.DTRESCISAOVINC IS NULL
        OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
GROUP BY  EM.NMESTRUTURAM, OH.NMOCUPACAOH, SG.DSSITUGERADORA
ORDER BY QTD_ACIDENTES DESC
OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 3260,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => 11,
       'P_NRESTRUTGEREN' => null,
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

public function getSituacaoGeradoraAcidenteOcupacaoGeral(
    $row
) {

   $sql = <<<SQL
    SELECT 'Ocupação: ' || OH.NMOCUPACAOH || ' || Situação Geradora ' || SG.DSSITUGERADORA AS INDICADOR, 
           COUNT(1) AS QTD_ACIDENTES,
           ROW_NUMBER() OVER (ORDER BY COUNT(1) DESC) AS rank_order
    FROM SST_VITIMA VI
    JOIN SST_OCORRENCIA OC ON OC.NRORG = VI.NRORG AND OC.NROCORRENCIA = VI.NROCORRENCIA
    LEFT JOIN SST_TIPOOCORRE TPO ON TPO.NRORG = OC.NRORG AND TPO.NRTIPOOCORRE = OC.NRTIPOOCORRE
    LEFT JOIN SST_SITUGERADORA SG ON SG.NRSITUGERADORA = TPO.NRSITUGERADORA 
                                   AND (SG.NRORG = TPO.NRORG OR SG.NRORG = 0)
    JOIN GPE_PESSOA PE ON PE.NRORG = VI.NRORG AND PE.NRPARCNEGOCIO = VI.NRPARCNEGOCIO
    JOIN GPE_VINCULOM VM ON VM.NRORG = VI.NRORG AND VM.NRPESSOA = PE.NRPESSOA
    JOIN GPE_VINCULOH VH ON VH.NRORG = VI.NRORG AND VH.NRVINCULOM = VM.NRVINCULOM
                         AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC)
                                                FROM GPE_VINCULOH H1
                                                WHERE H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND H1.NRORG = VM.NRORG
                                                  AND H1.NRVINCULOM = VM.NRVINCULOM)
    LEFT JOIN GPE_ALTEOCUPACAO AO ON AO.NRORG = VM.NRORG AND AO.NRVINCULOM = VM.NRVINCULOM
                                 AND AO.DTINIOCUPACAO = (SELECT MAX(DTINIOCUPACAO)
                                                       FROM GPE_ALTEOCUPACAO
                                                       WHERE NRORG = VM.NRORG
                                                         AND NRVINCULOM = VM.NRVINCULOM
                                                         AND DTINIOCUPACAO <= LAST_DAY(:P_DTMESCOMPETENC))
    LEFT JOIN GPE_OCUPACAOH OH ON AO.NROCUPACAOM = OH.NROCUPACAOM
                               AND OH.NRORG = AO.NRORG
                               AND OH.DTMESCOMPETENC = (SELECT MAX(OHH.DTMESCOMPETENC)
                                                      FROM GPE_OCUPACAOH OHH
                                                      WHERE OHH.NRORG = :P_NRORG
                                                        AND OHH.NROCUPACAOM = OH.NROCUPACAOM
                                                        AND OHH.DTMESCOMPETENC <= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY'))
    LEFT JOIN TIPOHIERARQORG TH ON (TH.NRORG = VM.NRORG OR TH.NRORG = 0)
                               AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
                               AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
    LEFT JOIN HIERARQUIAORG HO ON HO.NRORG = VM.NRORG
                              AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
                              AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
                              AND HO.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                              AND (HO.DTFIMVIGENCIA IS NULL OR HO.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
                              AND HO.DTINIVIGENCIA = (SELECT MAX(DTINIVIGENCIA)
                                                     FROM HIERARQUIAORG HI
                                                     WHERE HI.NRORG = HO.NRORG
                                                       AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
                                                       AND HI.NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
                                                       AND HI.DTINIVIGENCIA <= LAST_DAY(:P_DTMESCOMPETENC)
                                                       AND (HI.DTFIMVIGENCIA IS NULL OR HI.DTFIMVIGENCIA >= :P_DTMESCOMPETENC))
    LEFT JOIN ESTRUTURAM EMSUP ON EMSUP.NRESTRUTURAM = HO.NRESTRUTURAMSUP
                               AND EMSUP.NRORG = HO.NRORG
    WHERE VI.NRORG = :P_NRORG
      AND (VH.NRESTRUTLEGAL = :P_NRESTRUTLEGAL OR :P_NRESTRUTLEGAL IS NULL)
      AND (VH.NRESTRUTGEREN = :P_NRESTRUTGEREN OR :P_NRESTRUTGEREN IS NULL)
      AND (VH.NRESTRUTSIND = :P_NRESTRUTSIND OR :P_NRESTRUTSIND IS NULL)
      AND (HO.NRESTRUTURAMSUP = :P_NRESTRUTTOMAD OR :P_NRESTRUTTOMAD IS NULL)
      AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= TRUNC(SYSDATE))
    GROUP BY OH.NMOCUPACAOH, SG.DSSITUGERADORA
    ORDER BY QTD_ACIDENTES DESC
    OFFSET 0 ROWS FETCH NEXT 10 ROWS ONLY
SQL;

$query = $this->connection->prepare($sql);
$query->execute(
   array(
       'P_NRORG'       => 3260,//(int) $row['NRORG'],
       'P_DTMESCOMPETENC'   => '01/02/2024',//(string) $row['DTMESCOMPETENC'],
       'P_NRTIPOESTRUTOMADOR' => null,
       'P_NRESTRUTLEGAL' => 11,
       'P_NRESTRUTGEREN' => null,
       'P_NRESTRUTSIND' => null,
       'P_NRESTRUTTOMAD' => null,
       'P_NRTIPOESTRUTGEREN' => 6
   )
);

return $query->fetchAll();
}

}