<?php

namespace Eso\Controllers;

use Doctrine\ORM\EntityManager;
use Eso\Logic\ESocialLogic;
use Util\Environment;
use Util\Messages;
use Util\Util;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;

class EsoSimplificadoController {

    public function __construct (EntityManager $entityManager, Environment $environment){
        $this->entityManager = $entityManager;
        $this->environment = $environment;
    }

    public function enviarLoteEventoPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            
            $row = $request->getRow();
            
            $this->environment->setCdOperador($row['CDOPERADOR']);
            $this->environment->setDtCompetencia($row['DTMESCOMPETENC']);
            
            $logic = new ESocialLogic($this->entityManager, $this->environment, $row['DTMESCOMPETENC'], $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $logfile = Util::writeLogFile($this->environment->getNrOrgTrab(), 'called enviarLoteEventoPeriodico (Lote:'.$row['NRLOTE'].')',"consumer".$row['NRESOCONSUMER']);
            $msgRetorno = $logic->preparaEnviarLoteEvento(ESocialLogic::IDGRUPO_PERIODICO, $row['EVENTOS'], $row['NRLOTE'], $row['NRESOCONSUMER'], $logfile);
            $msgValidacao = $logic->getMessages();
            
            if (count($msgValidacao) > 0) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('enviarLoteEventoPeriodico', $msgValidacao));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Envio de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            Util::writeLogFile($this->environment->getNrOrgTrab(), 'error enviarLoteEventoPeriodico ('.$e->getMessage().')',"consumer".$row['NRESOCONSUMER']);
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function consultarProtocoloPeriodico(DTO\Request\Row $request, DTO\Response $response) {
        try {
            
            $row = $request->getRow();
            
            $this->environment->setCdOperador($row['CDOPERADOR']);
            $this->environment->setDtCompetencia($row['DTMESCOMPETENC']);
                
            $logic = new ESocialLogic($this->entityManager, $this->environment, $row['DTMESCOMPETENC'], $row['NRESTRUTURAM'], $row['NRTPAMBIENTE']);
            $logfile = Util::writeLogFile($this->environment->getNrOrgTrab(), 'called consultarProtocoloPeriodico',"consumer".$row['NRESOCONSUMER']);
            $msgRetorno = $logic->preparaConsultarLoteEvento(ESocialLogic::IDGRUPO_PERIODICO, $row, $row['NRESOCONSUMER'], $logfile);
            $msgValidacao = $logic->getMessages();
            
            if ($msgValidacao) {
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('consultarProtocoloPeriodico', array($msgValidacao)));
            } elseif ($msgRetorno) {
                $response->addMessage(new DTO\Response\Message($msgRetorno));
            } else {
                $response->addMessage(new DTO\Response\Message("Consulta de evento não disponível", DTO\Response\Message::TYPE_WARNING));
            }
        } catch(\Exception $e) {
            Util::writeLogFile($this->environment->getNrOrgTrab(), 'error consultarProtocoloPeriodico ('.$e->getMessage().')',"consumer".$row['NRESOCONSUMER']);
            if ($e->getCode() == Messages::ALERT_MESSAGE_CODE || $e->getCode() == Messages::ERROR_MESSAGE_CODE) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
}