<?php

namespace HCM\FPA\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\FPA\Services\RelatCustomAdmissaoService;
use HCM\Util\HCMParameters;
use HCM\Util\Util;

class RelatCustomAdmissaoController extends Crud {

    CONST operatorLikeAll = 'LIKE_ALL';
    CONST operatorLike = 'LIKE';

    public function __construct (Manager $dataSourceManager, HCMParameters $hcmParameters, RelatCustomAdmissaoService $relatCustomAdmissaoService){
        $this->relatCustomAdmissaoService = $relatCustomAdmissaoService;
        $this->hcmParameters = $hcmParameters;
        parent::__construct($dataSourceManager);
    }

    public function getRelatCustomAdmissao(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            set_time_limit(0);
            
            
            $filters = Util::removerCaracterePorcentagemString($request->getFilterCriteria()->getConditions());
            $parameters = array();
            $fieldsUnset = array('P_DTMESCOMPETENC', 'P_NRORG', 'VINCULOSATIVOS', 'CDMATRICULA', 'CDMATRICULAESOCIAL', 'LIST_NRESTRUTLEGAL', 'LIST_NRESTRUTGEREN', 'LIST_NRESTRUTSIND', 'LIST_NRSITUFUNCM', 'DTINIPERIODO', 'DTFIMPERIODO', 'P_NRORG_PADRAO', 'NRTIPOHIERARQORG', 'NRTIPOESTRUTURA', 'NRESTRUTSUPERIORM');
            foreach ($filters as $key => $filter) {
                if (array_search($filter['columnName'], $fieldsUnset) !== false){
                    unset($filters[$key]);
                }
                if($filter['operator'] == self::operatorLikeAll){
                    $filters[0]['operator'] = self::operatorLike;
                    $filters[0]['columnName'] = str_replace('|', '||', $filter['columnName']);
                }
                $parameters[$filter['columnName']] = $filter['value'];
            }
            
            $parameters['P_NRTIPOHIERARQORG'] = array_key_exists('NRTIPOHIERARQORG', $parameters) ? implode($parameters['NRTIPOHIERARQORG'], ',') : null;
            unset($parameters['NRTIPOHIERARQORG']);
            $parameters['P_NRTIPOESTRUTURA'] = array_key_exists('NRTIPOESTRUTURA', $parameters) ? implode($parameters['P_NRTIPOESTRUTURA'], ',') : null;
            unset($parameters['NRTIPOESTRUTURA']);
            $parameters['P_NRESTRUTSUPERIORM'] = array_key_exists('NRESTRUTSUPERIORM', $parameters) ? implode($parameters['NRESTRUTSUPERIORM'], ',') : null;
            unset($parameters['NRESTRUTSUPERIORM']);
            
            if($parameters['P_NRTIPOESTRUTURA'] || $parameters['P_NRTIPOHIERARQORG']){
                $params = array('P_NRORG'              => $parameters['P_NRORG'],
                                'P_NRTIPOHIERARQORG'   => $parameters['P_NRTIPOHIERARQORG'],
                                'P_NRTIPOESTRUTURA'    => $parameters['P_NRTIPOESTRUTURA'],
                                'P_DTMESCOMPETENC'     => $parameters['P_DTMESCOMPETENC']);
                $parameters['P_NOMETIPOSESTRUTURA'] = $this->relatCustomAdmissaoService->getNomeTipoEstrutura($params)[0]['NMTIPOESTRUTURA'];
                
            }
            
            $parameters['P_NRTPESTRUTMOVIM'] = array_key_exists('NRTPESTRUTMOVIM', $parameters) ? $parameters['NRTPESTRUTMOVIM'] : null;
            unset($parameters['NRTPESTRUTMOVIM']);
            
            $parameters['P_COMPANTERIOR'] = $this->hcmParameters->getDtCompAnterior();
            $result = $this->relatCustomAdmissaoService->getRelatCustomAdmissao($parameters, $filters);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('getRelatCustomAdmissao', $result));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }

    }
} 