<?php

namespace HCM\FPA\Services;

use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Doctrine\DBAL\Connection;
use HCM\Util\HCMParameters;
use HCM\Util\FPA;
use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\HTTP\Kernel;
use HCM\Util\Messages;
use HCM\Util\Util;
use HCM\Util\Repositories;


class CNABLeituraService {

    public function __construct (EntityManager $entityManager, HCMParameters $hcmParameters, Environment $environment, Kernel $httpKernel){
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->httpKernel = $httpKernel;
        $this->hcmParameters = $hcmParameters;
    }

    public function leituraArquivoBradesco200($row) {
        set_time_limit(0);
        
        $arquivo = $row['DSPATH'][0];
        $nmArquivo = explode('.', $arquivo['name'])[0];

        $file = $this->httpKernel->factoryFromFileData($arquivo, FPA::getTempDirectory()."/");
        
        if (!$file->isFile()) {
            throw new \Exception("Falha ao baixar o arquivo.");
        }
        
        $arquivo = file($file->getPathname());
        
        $data = array();
        
        foreach($arquivo as $key => $linha) {
            if($key == 0 && substr($linha, 2, 7) != 'RETORNO') {
                throw new \Exception("O arquivo não é de retorno.");
                break;
            } else if($key == 0) {
                $dtPagamento = substr($linha, 110, 2).'/'.substr($linha, 112, 2).'/'.substr($linha, 114, 4);
            } else if($key != 0 && $key != count($arquivo)-1) {
                $agencia = substr($linha, 63, 4);
                $codigo = substr($linha, 67, 4);
                $conta = substr($linha, 72, 7);
                $digitoConta = substr($linha, 79, 1);
                $nmvinculo = rtrim(substr($linha, 82, 38));
                $erros = substr($linha, 150, 2);

                $conta .= '-' . $digitoConta;

                $data[] = $this->montarDadosBradesco200($agencia, $codigo, $conta, $nmvinculo, $erros, $dtPagamento, $nmArquivo);
            }
        }
        
        $data['sucesso'] = 'Processo finalizado com sucesso!';
        return $data;
        
    }

    public function leituraArquivoBradesco240($row) {
        set_time_limit(0);
        
        $arquivo = $row['DSPATH'][0];
        $nmArquivo = explode('.', $arquivo['name'])[0];
        
        $file = $this->httpKernel->factoryFromFileData($arquivo, FPA::getTempDirectory()."/");
        
        if (!$file->isFile()) {
            throw new \Exception("Falha ao baixar o arquivo.");
        }
        
        $arquivo = file($file->getPathname());
        
        $data = array();
        
        /*******************************************************************************************
        *  Estilo de arquivo relacionado ao Bradesco 240 pos:                                      *
        *  2 Linhas de Header: Linha 0 e linha 1                                                   *
        *  2 Linhas por vínculo: Linha 2 e linha 3 -> 4 e 5 -> 6 e 7 -> ...                        *
        *  2 Linhas de Rodapé: Linhas finais do arquivo n-1 e n (onde n é o tamanho do arquivo)    *
        *  Caso necessário utlizar informações do rodapé, retirar o '-2' do for abaixo e fazer     *
        *  a verificação para ver se são as linhas finais do arquivo                               *
        ********************************************************************************************/
        for($key = 0; $key < count($arquivo)-2;) {
            if($key == 0) {
                $dataRetorno = substr($arquivo[$key], 143, 2) . '/' . substr($arquivo[$key], 145, 2) . '/' . substr($arquivo[$key], 147, 4);
                $horaRetorno = substr($arquivo[$key], 151, 2) . ':' . substr($arquivo[$key], 153, 2) . ':' . substr($arquivo[$key], 155, 2);
                $agenciaEmpresa = substr($arquivo[$key], 52, 5) . '-' . substr($arquivo[$key], 57, 1);
                $contaEmpresa = substr($arquivo[$key], 58, 13);
                $cnpjEmpresa = substr($arquivo[$key], 18, 12) . '-' . substr($arquivo[$key], 30, 2);
                
                $dataRetorno .= ' ' . $horaRetorno;
                
                $key++;
            } else if($key == 1) {
                $nomeEmpresa = substr($arquivo[$key], 72, 70);
                
                $key++;
            } else if($key > 1 && $key < count($arquivo)-1) {
                $nmvinculo = rtrim(substr($arquivo[$key], 43, 30));
                $ocorrencia = $this->verificaTipoOcorrencia(substr($arquivo[$key], 230, 2));
                $valor = ltrim(substr($arquivo[$key], 119, 14) . ',' . substr($arquivo[$key], 132, 2), '0');
                $banco = substr($arquivo[$key], 20, 3);
                $agencia = substr($arquivo[$key], 24, 4) . '-' . substr($arquivo[$key], 28, 1);
                $conta = substr($arquivo[$key], 29, 12) . '-' . substr($arquivo[$key], 41, 1);
                $dtPagamento = substr($arquivo[$key], 93, 2) . '/' . substr($arquivo[$key], 95, 2) . '/' . substr($arquivo[$key], 97, 4);

                // Verifica valor zerado para não retornar ',00'
                $valor = $this->verificaValorZerado($valor);

                $data[] = $this->montarDadosBradesco240($agenciaEmpresa, $contaEmpresa, $cnpjEmpresa, $nomeEmpresa, $dataRetorno, $nmvinculo, $ocorrencia, $valor, $banco, $agencia, $conta, $dtPagamento, $nmArquivo);

                $key = $key+2;
            }
        }

        $data['sucesso'] = 'Processo finalizado com sucesso!';
        return $data;
        
    }

    public function montarDadosBradesco200($agencia, $codigo, $conta, $nmvinculo, $erros, $dtPagamento, $nmArquivo) {
        // Divide cada caracter pra falara qual é o erro
        // Cada 'S' em posição diferente resulta em um erro diferente
        // S na posição 1 = Erro na Agência
        // S na posição 2 = Erro na Conta
        $mensagemErro = '';
        foreach(str_split($erros) as $key => $erro) {
            if($erro != ' ') {
                if($key == 0) {
                    $mensagemErro = "Erro na Agência";
                } else if($key == 1) {
                    if(empty($mensagemErro)) {
                        $mensagemErro = "Erro na Conta";
                    } else {
                        $mensagemErro .= " e Conta";
                    }
                }
            }
        }

        if(empty($mensagemErro)) {
            $mensagemErro = 'Sem erros';
        }
        
        $dado = array(
            'AGENCIA'       => $agencia,
            'CODIGO'        => $codigo,
            'CONTA'         => $conta,
            'NMVINCULO'     => $nmvinculo,
            'ERRO'          => $mensagemErro,
            'DTPAGAMENTO'   => $dtPagamento,
            'NMARQUIVO'     => $nmArquivo
        );

        return $dado;
    }

    public function montarDadosBradesco240($agenciaEmpresa, $contaEmpresa, $cnpjEmpresa, $nomeEmpresa, $dataRetorno, $nmvinculo, $ocorrencia, $valor, $banco, $agencia, $conta, $dtPagamento, $nmArquivo) {  
        $dado = array(
            'DTRETORNO'         => $dataRetorno,
            'NMEMPRESA'         => $nomeEmpresa,
            'AGENCIAEMPRESA'    => $agenciaEmpresa,
            'CONTAEMPRESA'      => $contaEmpresa,
            'CNPJEMPRESA'       => $cnpjEmpresa,
            'DTPAGAMENTO'       => $dtPagamento,
            'NMVINCULO'         => $nmvinculo,
            'BANCO'             => $banco,
            'VALOR'             => $valor,
            'AGENCIA'           => $agencia,
            'CONTA'             => $conta,
            'ERRO'              => $ocorrencia,
            'NMARQUIVO'         => $nmArquivo
        );

        return $dado;
    }
    
    public function verificaExistenciaArquivo($nmArquivo, $nrorg) {
        $registrosArquivo = $this->entityManager->getRepository(Repositories::FPA_RETORNOCNAB)->findBy(array('nrorg' => $nrorg, 'nmarquivo' => $nmArquivo));

        return $registrosArquivo;
    }

    public function verificaTipoOcorrencia($tpOcorrencia) {
        $tp = null;
        switch($tpOcorrencia) {
            case '00':
                $tp = "Crédito ou Débito Efetivado - Este código indica que o pagamento foi confirmado";
                break;
            case '01':
                $tp = "Insuficiência de Fundos - Débito Não Efetuado";
                break;
            case '02':
                $tp = "Crédito ou Débito Cancelado pelo Pagador/Credor";
                break;
            case '03':
                $tp = "Débito Autorizado pela Agência - Efetuado";
                break;
            case 'AA':
                $tp = "Controle Inválido";
                break;
            case 'AB':
                $tp = "Tipo de Operação Inválido";
                break;
            case 'AC':
                $tp = "Tipo de Serviço Inválido";
                break;
            case 'AD':
                $tp = "Forma de Lançamento Inválida";
                break;
            case 'AE':
                $tp = "Tipo/Número de Inscrição Inválido";
                break;
            case 'AF':
                $tp = "Código de Convênio Inválido";
                break;
            case 'AG':
                $tp = "Agência/Conta Corrente/DV Inválido";
                break;
            case 'AH':
                $tp = "Nº Sequencial do Registro no Lote Inválido";
                break;
            case 'AI':
                $tp = "Código de Segmento de Detalhe Inválido";
                break;
            case 'AJ':
                $tp = "Tipo de Movimento Inválido";
                break;
            case 'AK':
                $tp = "Código da Câmara de Compensação do Banco Favorecido/Depositário Inválido";
                break;
            case 'AL':
                $tp = "Código do Banco Favorecido Inoperante nesta data ou Depositário Inválido";
                break;
            case 'AM':
                $tp = "Agência Mantenedora da Conta Corrente do Favorecido Inválida";
                break;
            case 'AN':
                $tp = "Conta Corrente/DV do Favorecido Inválido";
                break;
            case 'AO':
                $tp = "Nome do Favorecido Não Informado";
                break;
            case 'AP':
                $tp = "Data Lançamento Inválido";
                break;
            case 'AQ':
                $tp = "Tipo/Quantidade da Moeda Inválido";
                break;
            case 'AR':
                $tp = "Valor do Lançamento Inválido";
                break;
            case 'AT':
                $tp = "Tipo/Número de Inscrição do Favorecido Inválido";
                break;
            case 'AU':
                $tp = "Logradouro do Favorecido Não Informado";
                break;
            case 'AV':
                $tp = "Nº do Local do Favorecido Não Informado";
                break;
            case 'AW':
                $tp = "Cidade do Favorecido Não Informada";
                break;
            case 'AX':
                $tp = "CEP/Complemento do Favorecido Inválido";
                break;
            case 'AY':
                $tp = "Sigla do Estado do Favorecido Inválida";
                break;
            case 'AZ':
                $tp = "Código/Nome do Banco Depositário Inválido";
                break;
            case 'BA':
                $tp = "Código/Nome da Agência Depositária Não Informado";
                break;
            case 'BB':
                $tp = "Seu Número Inválido";
                break;
            case 'BC':
                $tp = "Nosso Número Inválido";
                break;
            case 'BD':
                $tp = "Inclusão Efetuada com Sucesso";
                break;
            case 'BE':
                $tp = "Alteração Efetuada com Sucesso";
                break;
            case 'BF':
                $tp = "Exclusão Efetuada com Sucesso";
                break;
            case 'BG':
                $tp = "Agência/Conta Impedida Legalmente";
                break;
            case 'BH':
                $tp = "Empresa não pagou salário";
                break;
            case 'BI':
                $tp = "Falecimento do mutuário";
                break;
            case 'BJ':
                $tp = "Empresa não enviou remessa do mutuário";
                break;
            case 'BK':
                $tp = "Empresa não enviou remessa no vencimento";
                break;
            case 'BL':
                $tp = "Valor da parcela inválida";
                break;
            case 'BM':
                $tp = "Identificação do contrato inválida";
                break;
            case 'BN':
                $tp = "Operação de Consignação Incluída com Sucesso";
                break;
            case 'BO':
                $tp = "Operação de Consignação Alterada com Sucesso";
                break;
            case 'BP':
                $tp = "Operação de Consignação Excluída com Sucesso";
                break;
            case 'BQ':
                $tp = "Operação de Consignação Liquidada com Sucesso";
                break;
            case 'CA':
                $tp = "Código de Barras - Código do Banco Inválido";
                break;
            case 'CB':
                $tp = "Código de Barras - Código da Moeda Inválido";
                break;
            case 'CC':
                $tp = "Código de Barras - Dígito Verificador Geral Inválido";
                break;
            case 'CD':
                $tp = "Código de Barras - Valor do Título Divergente/Inválido";
                break;
            case 'CE':
                $tp = "Código de Barras - Campo Livre Inválido";
                break;
            case 'CF':
                $tp = "Valor do Documento Inválido";
                break;
            case 'CG':
                $tp = "Valor do Abatimento Inválido";
                break;
            case 'CH':
                $tp = "Valor do Desconto Inválido";
                break;
            case 'CI':
                $tp = "Valor de Mora Inválido";
                break;
            case 'CJ':
                $tp = "Valor da Multa Inválido";
                break;
            case 'CK':
                $tp = "Valor do IR Inválido";
                break;
            case 'CL':
                $tp = "Valor do ISS Inválido";
                break;
            case 'CM':
                $tp = "Valor do IOF Inválido";
                break;
            case 'CN':
                $tp = "Valor de Outras Deduções Inválido";
                break;
            case 'CO':
                $tp = "Valor de Outros Acréscimos Inválido";
                break;
            case 'CP':
                $tp = "Valor do INSS Inválido";
                break;
            case 'HA':
                $tp = "Lote Não Aceito";
                break;
            case 'HB':
                $tp = "Inscrição da Empresa Inválida para o Contrato";
                break;
            case 'HC':
                $tp = "Convênio com a Empresa Inexistente/Inválido para o Contrato";
                break;
            case 'HD':
                $tp = "Agência/Conta Corrente da Empresa Inexistente/Inválido para o Contrato";
                break;
            case 'HE':
                $tp = "Tipo de Serviço Inválido para o Contrato";
                break;
            case 'HF':
                $tp = "Conta Corrente da Empresa com Saldo Insuficiente";
                break;
            case 'HG':
                $tp = "Lote de Serviço Fora de Sequência";
                break;
            case 'HH':
                $tp = "Lote de Serviço Inválido";
                break;
            case 'HI':
                $tp = "Arquivo não aceito";
                break;
            case 'HJ':
                $tp = "Tipo de Registro Inválido";
                break;
            case 'HK':
                $tp = "Código Remessa / Retorno Inválido";
                break;
            case 'HL':
                $tp = "Versão de layout inválida";
                break;
            case 'HM':
                $tp = "Mutuário não identificado";
                break;
            case 'HN':
                $tp = "Tipo do benefício não permite empréstimo";
                break;
            case 'HO':
                $tp = "Benefício cessado/suspenso";
                break;
            case 'HP':
                $tp = "Benefício possui representante legal";
                break;
            case 'HQ':
                $tp = "Benefício é do tipo PA (Pensão alimentícia)";
                break;
            case 'HR':
                $tp = "Quantidade de contratos permitida excedida";
                break;
            case 'HS':
                $tp = "Benefício não pertence ao Banco informado";
                break;
            case 'HT':
                $tp = "Início do desconto informado já ultrapassado";
                break;
            case 'HU':
                $tp = "Número da parcela inválida";
                break;
            case 'HV':
                $tp = "Quantidade de parcela inválida";
                break;
            case 'HW':
                $tp = "Margem consignável excedida para o mutuário dentro do prazo do contrato";
                break;
            case 'HX':
                $tp = "Empréstimo já cadastrado";
                break;
            case 'HY':
                $tp = "Empréstimo inexistente";
                break;
            case 'HZ':
                $tp = "Empréstimo já encerrado";
                break;
            case 'H1':
                $tp = "Arquivo sem trailer";
                break;
            case 'H2':
                $tp = "Mutuário sem crédito na competência";
                break;
            case 'H3':
                $tp = "Não descontado - outros motivos";
                break;
            case 'H4':
                $tp = "Retorno de Crédito não pago";
                break;
            case 'H5':
                $tp = "Cancelamento de empréstimo retroativo";
                break;
            case 'H6':
                $tp = "Outros Motivos de Glosa";
                break;
            case 'H7':
                $tp = "Margem consignável excedida para o mutuário acima do prazo do contrato";
                break;
            case 'H8':
                $tp = "Mutuário desligado do empregador";
                break;
            case 'H9':
                $tp = "Mutuário afastado por licença";
                break;
            case 'IA':
                $tp = "Primeiro nome do mutuário diferente do primeiro nome do movimento do censo ou diferente da base de Titular do Benefício";
                break;
            case 'TA':
                $tp = "Lote Não Aceito - Totais do Lote com Diferença";
                break;
            case 'YA':
                $tp = "Título Não Encontrado";
                break;
            case 'YB':
                $tp = "Identificador Registro Opcional Inválido";
                break;
            case 'YC':
                $tp = "Código Padrão Inválido";
                break;
            case 'YD':
                $tp = "Código de Ocorrência Inválido";
                break;
            case 'YE':
                $tp = "Complemento de Ocorrência Inválido";
                break;
            case 'YF':
                $tp = "Alegação já Informada";
                break;
            case 'ZA':
                $tp = "Agência/Conta do Favorecido Substituída";
                break;
            case 'ZB':
                $tp = "Divergência entre o primeiro e último nome do beneficiário versus primeiro e último nome na Receita Federal";
                break;
            case 'ZC':
                $tp = "Confirmação de Antecipação de Valor";
                break;
            case 'ZD':
                $tp = "Antecipação Parcial de Valor";
                break;
            case 'ZE':
                $tp = "Título bloqueado na base";
                break;
            case 'ZF':
                $tp = "Sistema em contingência - título valor maior que referência";
                break;
            case 'ZG':
                $tp = "Sistema em contingência - título vencido";
                break;
            case 'ZH':
                $tp = "Sistema em contingência - título indexado";
                break;
            case 'ZI':
                $tp = "Beneficiário divergente - Dados do Beneficiário divergente do constante na CIP";
                break;
            case 'ZJ':
                $tp = "Limite de pagamentos parciais excedidos";
                break;
            case 'ZK':
                $tp = "Boleto já liquidado - Título de cobrança já liquidado na base da CIP";
                break;
            case '5A':
                $tp = "Agendado sob lista de debito";
                break;
            case '5B':
                $tp = "Pagamento não autoriza sob lista de debito";
                break;
            case '5C':
                $tp = "Lista com mais de uma modalidade";
                break;
            case '5D':
                $tp = "Lista com mais de uma data de pagamento";
                break;
            case '5E':
                $tp = "Número de lista duplicado";
                break;
            case '5F':
                $tp = "Lista de debito vencida e não autorizada";
                break;
            case '5I':
                $tp = "Ordem de Pagamento emitida";
                break;
            case '5J':
                $tp = "Ordem de pagamento com data limite vencida";
                break;
            case '5M':
                $tp = "Número de lista de debito invalida";
                break;
            case '5T':
                $tp = "Pagamento realizado em contrato na condição de TESTE";
                break;
            default:
                $tp = "Tipo de ocorrência desconhecida - " . $tpOcorrencia;
                break;
        }

        return $tp;
    }

    public function verificaTipoBeneficiario($tpBeneficiario) {
        $tp = null;
        switch($tpBeneficiario) {
            case 0:
                $tp = "Isento / Não Informado - ";
                break;
            case 1:
                $tp = "CPF - ";
                break;
            case 2: 
                $tp = "CNPJ - ";
                break;
            case 3: 
                $tp = "PIS / PASEP - ";
                break;
            case 9: 
                $tp = "Outro - ";
                break;
            default:
                $tp = "Tipo inválido - ";
                break;
        }

        return $tp;
    }

    public function verificaValorZerado($campo) {
        if(empty($campo) || $campo == ',00') {
            return '0,00';
        } else {
            return $campo;
        }
    }

}