<?php

namespace HCM\FPA\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Error;
use \HCM\FPA\Repository\LogRetrocessoCalculoRepository;


class LogRetrocessoCalculoService {
    
    protected $entityManager;
    protected $hcmParameters;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, LogRetrocessoCalculoRepository $logRetrocessoCalculoRepository) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->logRetrocessoCalculoRepository = $logRetrocessoCalculoRepository;
    }

    public function persistirLogRetrocesso($tpCalc, $row){
        try{
            
            $rowForm = clone $row;
            
            if(is_numeric($tpCalc)) $tpCalc = $this->entityManager->getRepository(Repositories::FPA_TIPOCALCULO)->findOneBy(['nrtipocalculo' => $tpCalc])->getNmtipocalculo();
            
            if(isset($rowForm['IDRETROCESSO']) && !empty($rowForm['IDRETROCESSO'])) $rowForm['IDMEMORIACALC'] = $rowForm['IDRETROCESSO'];
    
            // Diferentes validações para os difetentes tipos de ordem
            if($rowForm['DSORDEM'] == "ALFABETICA"){
                if(isset($rowForm['NMINIVINCULOM']) && !empty($rowForm['NMINIVINCULOM'])) $rowForm['DSINICIO'] = $rowForm['NMINIVINCULOM'];
                if(isset($rowForm['NMFIMVINCULOM']) && !empty($rowForm['NMFIMVINCULOM'])) $rowForm['DSFIM'] = $rowForm['NMFIMVINCULOM'];
            } 
            elseif($rowForm['DSORDEM'] == "MATRICULA"){
                if(isset($rowForm['CDINIMATRICULA']) && !empty($rowForm['CDINIMATRICULA'])) $rowForm['DSINICIO'] = $rowForm['CDINIMATRICULA'];
                if(isset($rowForm['CDFIMMATRICULA']) && !empty($rowForm['CDFIMMATRICULA'])) $rowForm['DSFIM'] = $rowForm['CDFIMMATRICULA'];
            }
            elseif($rowForm['DSORDEM'] == "DATA_ADMISSAO"){
                if(isset($rowForm['DSINICIOVALE']) && !empty($rowForm['DSINICIOVALE'])) $rowForm['DSINICIO'] = $rowForm['DSINICIOVALE'];
                if(isset($rowForm['DSFIMVALE']) && !empty($rowForm['DSFIMVALE'])) $rowForm['DSFIM'] = $rowForm['DSFIMVALE'];
                if(isset($rowForm['DSINICIOCALCBENEF']) && !empty($rowForm['DSINICIOCALCBENEF'])) $rowForm['DSINICIO'] = $rowForm['DSINICIOCALCBENEF'];
                if(isset($rowForm['DSFIMCALCBENEF']) && !empty($rowForm['DSFIMCALCBENEF'])) $rowForm['DSFIM'] = $rowForm['DSFIMCALCBENEF'];
                if(isset($rowForm['DTINIADMISSAO']) && !empty($rowForm['DTINIADMISSAO'])) $rowForm['DSINICIO'] = $rowForm['DTINIADMISSAO'];
                if(isset($rowForm['DTFIMADMISSAO']) && !empty($rowForm['DTFIMADMISSAO'])) $rowForm['DSFIM'] = $rowForm['DTFIMADMISSAO'];
            }
            elseif($rowForm['DSORDEM'] == "ESTRUTURA"){
                if(isset($rowForm['NMESTRUTLEGAL']) && !empty($rowForm['NMESTRUTLEGAL'])) $rowForm['DSINICIO'] = $rowForm['NMESTRUTLEGAL'];
                if(isset($rowForm['NMESTRUTGEREN']) && !empty($rowForm['NMESTRUTGEREN'])) $rowForm['DSFIM'] = $rowForm['NMESTRUTGEREN'];
            }
            elseif($rowForm['DSORDEM'] == "LISTA_ESTRUTURA"){
                if(isset($rowForm['LIST_NMESTRUTLEGAL']) && !empty($rowForm['LIST_NMESTRUTLEGAL'])) $rowForm['DSINICIO'] = implode(", ", $rowForm['LIST_NMESTRUTLEGAL']);
                if(isset($rowForm['LIST_NMESTRUTGEREN']) && !empty($rowForm['LIST_NMESTRUTGEREN'])) $rowForm['DSFIM'] = implode(", ", $rowForm['LIST_NMESTRUTGEREN']);
            }
            else if ($rowForm['DSORDEM'] == "LISTA_TOMADOR"){
                if(isset($rowForm['LIST_NMESTRUTURAMSUP']) && !empty($rowForm['LIST_NMESTRUTURAMSUP'])) $rowForm['DSINICIO'] = implode(", ", $rowForm['LIST_NMESTRUTURAMSUP']);
                if(isset($rowForm['LIST_NMESTRUTGEREN']) && !empty($rowForm['LIST_NMESTRUTGEREN'])) $rowForm['DSFIM'] = implode(", ", $rowForm['LIST_NMESTRUTGEREN']);
            }
            elseif($rowForm['DSORDEM'] == "LISTA_NRESTRUTSIND"){
                if(isset($rowForm['NMESTRUTLEGAL']) && !empty($rowForm['NMESTRUTLEGAL'])) $rowForm['DSINICIO'] = $rowForm['NMESTRUTLEGAL'];
                if(isset($rowForm['LIST_NMESTRUTSIND']) && !empty($rowForm['LIST_NMESTRUTSIND'])) $rowForm['DSFIM'] = implode(", ", $rowForm['LIST_NMESTRUTSIND']);
            }
            elseif($rowForm['DSORDEM'] == "LISTA_VINCULO"){
                if(isset($rowForm['NMVINCULOM']) && !empty($rowForm['NMVINCULOM']) && is_array($rowForm['NMVINCULOM'])) $rowForm['DSINICIO'] = implode(", ", $rowForm['NMVINCULOM']);
                if(isset($rowForm['NMVINCULOM']) && !empty($rowForm['NMVINCULOM']) && !is_array($rowForm['NMVINCULOM'])) $rowForm['DSINICIO'] =  $rowForm['NMVINCULOM'];
            }
            elseif($rowForm['DSORDEM'] == "LISTA_LOTE"){
                if(isset($rowForm['LIST_NMLOTEVINC']) && !empty($rowForm['LIST_NMLOTEVINC']) && is_array($rowForm['LIST_NMLOTEVINC'])) $rowForm['DSINICIO'] = implode(", ", $rowForm['LIST_NMLOTEVINC']);
                if(isset($rowForm['NMLOTEVINC']) && !empty($rowForm['NMLOTEVINC']) && !is_array($rowForm['NMLOTEVINC'])) $rowForm['DSINICIO'] =  $rowForm['NMLOTEVINC'];
            }
            elseif($rowForm['DSORDEM'] == "ESTRUT_ALFABETICA_TPVINC"){
                if(isset($rowForm['LIST_NMESTRUTLEGAL']) && !empty($rowForm['LIST_NMESTRUTLEGAL'])) $rowForm['DSINICIO'] = implode(", ", $rowForm['LIST_NMESTRUTLEGAL']);
                if(isset($rowForm['LIST_NMESTRUTGEREN']) && !empty($rowForm['LIST_NMESTRUTGEREN'])) $rowForm['DSFIM'] = implode(", ", $rowForm['LIST_NMESTRUTGEREN']);
                if(isset($rowForm['NMVINCULOM_INI']) && !empty($rowForm['NMVINCULOM_INI'])) $rowForm['DSINICIO2'] = $rowForm['NMVINCULOM_INI'];
                if(isset($rowForm['NMVINCULOM_FIM']) && !empty($rowForm['NMVINCULOM_FIM'])) $rowForm['DSFIM2'] = $rowForm['NMVINCULOM_FIM'];
                if(isset($rowForm['NMTIPOVINCULO']) && !empty($rowForm['NMTIPOVINCULO'])) $rowForm['DSINICIO3'] = implode(", ", $rowForm['NMTIPOVINCULO']);
            }
            elseif($rowForm['DSORDEM'] == "LISTA_BENEFICIO"){
                if(isset($rowForm['LIST_NRBENEFICIOM']) && !empty($rowForm['LIST_NRBENEFICIOM'])) $rowForm['DSINICIO'] = implode(", ", $rowForm['LIST_NRBENEFICIOM']);
            }

            // Benefício e VT
            if($tpCalc == 'CALC_BENEFICIO' || $tpCalc == 'CALC_VT'){
                if(isset($rowForm['DTINICALCBENEF']) && !empty($rowForm['DTINICALCBENEF'])) $rowForm['DTINICIOVALE'] = $rowForm['DTINICALCBENEF'];
                if(isset($rowForm['DTFIMCALCBENEF']) && !empty($rowForm['DTFIMCALCBENEF'])) $rowForm['DTFINALVALE'] = $rowForm['DTFIMCALCBENEF'];
                if(isset($rowForm['DTPGTOCALCBENEF']) && !empty($rowForm['DTPGTOCALCBENEF'])) $rowForm['DTPAGAMENTO'] = $rowForm['DTPGTOCALCBENEF'];
                if(isset($rowForm['DTPAGAMENTOVALE']) && !empty($rowForm['DTPAGAMENTOVALE'])) $rowForm['DTPAGAMENTO'] = $rowForm['DTPAGAMENTOVALE'];
            }    

            // Contabilização Mensal
            if($tpCalc == 'CALC_CONTAB'){
                if(isset($rowForm['NMTIPOMOVIMENT']) && !empty($rowForm['NMTIPOMOVIMENT'])) $rowForm['DSINICIO2'] = $rowForm['NMTIPOMOVIMENT'];
                if(isset($rowForm['NROCORRECAL']) && !empty($rowForm['NROCORRECAL'])) $rowForm['DSFIM2'] = $rowForm['NROCORRECAL'];
                
                if(isset($rowForm['IDFORMACONTAB']) && !empty($rowForm['IDFORMACONTAB']) && $rowForm['IDFORMACONTAB'] == 'T') $rowForm['DSINICIO3'] = "Ambos";
                elseif(isset($rowForm['IDFORMACONTAB']) && !empty($rowForm['IDFORMACONTAB']) && $rowForm['IDFORMACONTAB'] == 'C') $rowForm['DSINICIO3'] = "Gera Contabilização";
                elseif(isset($rowForm['IDFORMACONTAB']) && !empty($rowForm['IDFORMACONTAB']) && $rowForm['IDFORMACONTAB'] == 'D') $rowForm['DSINICIO3'] = "Gera Despesas";
            }
    
            //ORDEM LISTA ESTRUTURA
    
            $params = array(
                "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                "P_NRLOGRETROCESSO" => \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'FPA_LOGRETROCESSO', 1, 12, true),
                "P_DTINCLUSAO" => $this->hcmParameters->getDataAtual(false),
                "P_CDOPERINCLUSAO" => $this->hcmParameters->getCdoperador(),
                "P_DSORDEM" => isset($rowForm['DSORDEM']) && !empty($rowForm['DSORDEM']) ? $rowForm['DSORDEM'] : null,
                "P_DSINICIO" => isset($rowForm['DSINICIO']) && !empty($rowForm['DSINICIO']) ? $rowForm['DSINICIO'] : null,
                "P_DSFIM" => isset($rowForm['DSFIM']) && !empty($rowForm['DSFIM']) ? $rowForm['DSFIM'] : null,
                "P_DTPAGAMENTO" => isset($rowForm['DTPAGAMENTO']) && !empty($rowForm['DTPAGAMENTO']) ? $rowForm['DTPAGAMENTO'] : null,
                "P_IDULTPGTOMES" => isset($rowForm['IDULTPGTOMES']) && !empty($rowForm['IDULTPGTOMES']) ? $rowForm['IDULTPGTOMES'] : null,
                "P_IDMEMORIACALC" => isset($rowForm['IDMEMORIACALC']) && !empty($rowForm['IDMEMORIACALC']) ? $rowForm['IDMEMORIACALC'] : null,
                "P_IDTPFORMCALCULO" => $tpCalc,
                "P_IDDIFSAL" => isset($rowForm['IDDIFSAL']) && !empty($rowForm['IDDIFSAL']) ? $rowForm['IDDIFSAL'] : null,
                "P_IDDIFFERIAS" => isset($rowForm['IDDIFFERIAS']) && !empty($rowForm['IDDIFFERIAS']) ? $rowForm['IDDIFFERIAS'] : null,
                "P_DSTIPOVINCULO" => isset($rowForm['DSTIPOVINCULO']) && !empty($rowForm['DSTIPOVINCULO']) ? $rowForm['DSTIPOVINCULO'] : null,
                "P_DSINICIO2" => isset($rowForm['DSINICIO2']) && !empty($rowForm['DSINICIO2']) ? $rowForm['DSINICIO2'] : null,
                "P_DSFIM2" => isset($rowForm['DSFIM2']) && !empty($rowForm['DSFIM2']) ? $rowForm['DSFIM2'] : null,
                "P_DSINICIO3" => isset($rowForm['DSINICIO3']) && !empty($rowForm['DSINICIO3']) ? $rowForm['DSINICIO3'] : null,
                "P_DSFIM3" => isset($rowForm['DSFIM3']) && !empty($rowForm['DSFIM3']) ? $rowForm['DSFIM3'] : null,
                "P_NRFERIAS" => isset($rowForm['NRFERIAS']) && !empty($rowForm['NRFERIAS']) ? $rowForm['NRFERIAS'] : null,
                "P_DTINIGOZOFERIAS" => isset($rowForm['DTINIGOZOFERIAS']) && !empty($rowForm['DTINIGOZOFERIAS']) ? $rowForm['DTINIGOZOFERIAS'] : null,
                "P_DTFIMGOZOFERIAS" => isset($rowForm['DTFIMGOZOFERIAS']) && !empty($rowForm['DTFIMGOZOFERIAS']) ? $rowForm['DTFIMGOZOFERIAS'] : null,
                "P_QTDIAGOZOFERIAS" => isset($rowForm['QTDIAGOZOFERIAS']) && !empty($rowForm['QTDIAGOZOFERIAS']) ? $rowForm['QTDIAGOZOFERIAS'] : null,
                "P_QTDIASABONOFERI" => isset($rowForm['QTDIASABONOFERI']) && !empty($rowForm['QTDIASABONOFERI']) ? $rowForm['QTDIASABONOFERI'] : null,
                "P_NRVINCULOM" => isset($rowForm['NRVINCULOM']) && !empty($rowForm['NRVINCULOM']) ? $rowForm['NRVINCULOM'] : null,
                "P_DTAVISOFERIAS" => isset($rowForm['DTAVISOFERIAS']) && !empty($rowForm['DTAVISOFERIAS']) ? $rowForm['DTAVISOFERIAS'] : null,
                "P_IDADIANT13SALAR" => isset($rowForm['IDADIANT13SALAR']) && !empty($rowForm['IDADIANT13SALAR']) ? $rowForm['IDADIANT13SALAR'] : null,
                "P_DSVINCNAOCONTEMPL" => isset($rowForm['DSVINCNAOCONTEMPL']) && !empty($rowForm['DSVINCNAOCONTEMPL']) ? $rowForm['DSVINCNAOCONTEMPL'] : null,
                "P_DTRESCISAOINI" => isset($rowForm['DTRESCISAOINI']) && !empty($rowForm['DTRESCISAOINI']) ? $rowForm['DTRESCISAOINI'] : null,
                "P_DTRESCISAOFIM" => isset($rowForm['DTRESCISAOFIM']) && !empty($rowForm['DTRESCISAOFIM']) ? $rowForm['DTRESCISAOFIM'] : null,
                "P_VRSALDOFGTSBANCO" => isset($rowForm['VRSALDOFGTSBANCO']) && !empty($rowForm['VRSALDOFGTSBANCO']) ? $rowForm['VRSALDOFGTSBANCO'] : null,
                "P_IDFAZDIFCOMP" => isset($rowForm['IDFAZDIFCOMP']) && !empty($rowForm['IDFAZDIFCOMP']) ? $rowForm['IDFAZDIFCOMP'] : null,
                "P_VRSALDISSIDIO" => isset($rowForm['VRSALDISSIDIO']) && !empty($rowForm['VRSALDISSIDIO']) ? $rowForm['VRSALDISSIDIO'] : null,
                "P_DTINICIOVALE" => isset($rowForm['DTINICIOVALE']) && !empty($rowForm['DTINICIOVALE']) ? $rowForm['DTINICIOVALE'] : null,
                "P_DTFINALVALE" => isset($rowForm['DTFINALVALE']) && !empty($rowForm['DTFINALVALE']) ? $rowForm['DTFINALVALE'] : null,
                "P_DTINICIOFILTROVALE" => isset($rowForm['DTINICIOFILTROVALE']) && !empty($rowForm['DTINICIOFILTROVALE']) ? $rowForm['DTINICIOFILTROVALE'] : null,
                "P_DTFINALFILTROVALE" => isset($rowForm['DTFINALFILTROVALE']) && !empty($rowForm['DTFINALFILTROVALE']) ? $rowForm['DTFINALFILTROVALE'] : null,
                "P_NRTIPOLINHAVINC" => isset($rowForm['NRTIPOLINHAVINC']) && !empty($rowForm['NRTIPOLINHAVINC']) ? $rowForm['NRTIPOLINHAVINC'] : null,
                "P_NRTPBENEFICIO" => isset($rowForm['NRTPBENEFICIO']) && !empty($rowForm['NRTPBENEFICIO']) ? $rowForm['NRTPBENEFICIO'] : null,
                "P_TPPERIODOBENEF" => isset($rowForm['TPPERIODOBENEF']) && !empty($rowForm['TPPERIODOBENEF']) ? $rowForm['TPPERIODOBENEF'] : null,
                "P_DSOBSERVACAO" => isset($rowForm['DSOBSERVACAO']) && !empty($rowForm['DSOBSERVACAO']) ? $rowForm['DSOBSERVACAO'] : null,
            );
            $this->logRetrocessoCalculoRepository->persistirLogRetrocesso($params);

        } catch (\Exception $e) {
			// Retrocesso não deve parar por erro ao gravar no log
		}
    
    }

}