<?php
namespace HCM\Geral\Services;

use Doctrine\ORM\EntityManager;
use HCM\Geral\Repository\ESocialRepository;
use HCM\Geral\Services\UploadFileService;
use HCM\Util\DateUtil;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;

class EsoParametroService {

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, ESocialRepository $esocialRepository, UploadFileService $uploadsFileService) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->eSocialRepository = $esocialRepository;
        $this->uploadsFileService = $uploadsFileService;
    }

    public function setDadosCertificado($row) {
        try {
            $esoParametro = $this->entityManager->getRepository(Repositories::ESO_PARAMETRO)->findOneBy(
                array('nrorg' => $this->hcmParameters->getNrorgTrabalho(), 'nrparametro' => $row['NRPARAMETRO'])
            );
            
            // Apaga o arquivo antigo do FileServer caso exista
            if ($esoParametro->getDsarqucert()) {
                $this->uploadsFileService->deleteUploadFile($esoParametro->getDsarqucert());
            }
            
            // Insere o novo arquivo
            $upload = $this->uploadsFileService->setGpeAnexos($row);
            
            
            // Atualiza o caminho do arquivo e a senha no parametro
            $esoParametro->setDsarqucert($row['DSPATH'][0]["path"]);
            $esoParametro->setDssenhacert($row['DSSENHACERT']);
            
            $dtValidadeCertif = $this->pegarDtValidadeDoCertificado($esoParametro);
            
            $esoParametro->setDtvalidadecert($dtValidadeCertif);
            $esoParametro->setDtultatu(DateUtil::getDataAtual());
            $esoParametro->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
            $esoParametro->setCdoperultatu($this->hcmParameters->getCdoperador());
            $this->entityManager->persist($esoParametro);
            $this->entityManager->flush();
            
            
            return $upload;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function verificaVersaoNova($row) {
        try {
            $esoParametro = $this->entityManager->getRepository(Repositories::ESO_PARAMETRO)->findOneBy(array('nrorg' => $row['NRORG'], 'nrparametro' => $row['NRPARAMETRO']));
            
            if (is_object($esoParametro)) {
                if ($esoParametro->getDsversao() != $row['DSVERSAO']) {
                    $this->entityManager->beginTransaction();
                    $update = $this->eSocialRepository->updateEnvioVersao($row['NRORG'], $row['NRESTRUTURAM'], $row['DSVERSAO']);
                    if ($update) {
                        $this->entityManager->commit();
                    } else {
                        throw new \Exception(Messages::SAVE_ERROR_MESSAGE);
                    }
                }
            }
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    private function pegarDtValidadeDoCertificado($esoParametro) {
        $validadeCert;
        $parcnegocio = $this->entityManager->getRepository(Repositories::PARCNEGOCIO)->findOneBy(
            array('nrorg'=>$this->hcmParameters->getNrorgTrabalho(), 'nrparcnegocio'=>$esoParametro->getNrparcnegocio())
        );
        
        
        $this->tempEsocialPath = $this->hcmParameters->getTempDirectory() . DIRECTORY_SEPARATOR . "esocial";
        
        $this->nrInscTransmissor = $parcnegocio->getNrinscricaoparc();
        
        $this->certificatesPath = $this->hcmParameters->getFileServerDirectory();
        $this->tempCertificatesPath = $this->tempEsocialPath . DIRECTORY_SEPARATOR . "certificates" . DIRECTORY_SEPARATOR . $this->hcmParameters->getNrorgTrabalho();
        
        
        $this->certFile = $this->certificatesPath . $esoParametro->getDsarqucert();
        $this->certKeyFile = $this->tempCertificatesPath . DIRECTORY_SEPARATOR . "certKey" . $this->nrInscTransmissor . ".pem";
        $this->certPass = $esoParametro->getDssenhacert();
        
        // SOLUÇÃO NOVO FILESERVER	 
        // $this->certFile = Util::buscaArquivoFileServer($this->certFile, '.pfx');	 
        // // $this->certFile é o conteúdo do arquivo buscado	 
        // // comentar linha "$this->certFile = file_get_contents($this->certFile);", pois já retornado o conteúdo do arquivo
        
        // Variável criada para realizar 5 tentativas de acessar o cetificado no FileServer antes de retornar o erro
        $openCertFile = false;
        
        /* Retira possíveis warnings do php ao usar fopen no fileServer */
        error_reporting(E_ALL ^ E_WARNING);
        for ($i=0;$i<5;$i++) {
            if (fopen($this->certFile,"r") == true) {
                $openCertFile = true;
                break;
            }
        }
        error_reporting(E_ALL ^ E_NOTICE);
        
        if ($openCertFile) {
            if (file_exists($this->certKeyFile)) {
                unlink($this->certKeyFile);
            }
            if (!file_exists($this->certKeyFile)) {
                if (!is_dir($this->tempCertificatesPath)) {
                    mkdir($this->tempCertificatesPath, 0777, true);
                }
                // Alteração temporária para ler somente uma vez o arquivo do FileServer e armazenar na variável certFile
                //$data = file_get_contents($this->certFile);
                //openssl_pkcs12_read($data, $cert, $this->certPass);
                $this->certFile = file_get_contents($this->certFile);
                openssl_pkcs12_read($this->certFile, $cert, $this->certPass);
                
                if (is_null($cert)) {
                        throw new \Exception(Messages::HCM09000_ESO_GENERATE_CERT_KEY_ERROR, Messages::ERROR_MESSAGE_CODE);
                } else {
                    //Dados do certificado
                    $dados = array ();
                    $dados = openssl_x509_parse( openssl_x509_read($cert['cert']) );
                    
                    //Dados mais importantes
                    //$dados['subject']['C']; //País
                    //$dados['subject']['ST']; //Estado
                    //$dados['subject']['L']; //Município
                    //$dados['subject']['CN']; //Razão Social e CNPJ / CPF
                    $validadeCert = date('d/m/Y', $dados['validTo_time_t']);//Validade	
                    $validadeCert = DateUtil::getDataDeString($validadeCert, DateUtil::FORMATO_BRASILEIRO, true);
                    //$dados['extensions']['subjectAltName'];	//Emails Cadastrados separado por ,
                }
            }
        } else {
            throw new \Exception(Messages::HCM09000_ESO_CERTIFICADO_NOT_OPEN_ERROR, Messages::ERROR_MESSAGE_CODE);
        }
        
        $dataAtual = date('d/m/Y');
        $dataAtual = DateUtil::getDataDeString($dataAtual, DateUtil::FORMATO_BRASILEIRO, true);
        // Verifica se a validade é anterior à data atual
        if (DateUtil::comparaDatas($validadeCert, $dataAtual)) {
                throw new \Exception(Messages::HCM09000_ESO_CERTIFICADO_VALIDADE_ERROR, Messages::ERROR_MESSAGE_CODE);
        }
        
        return $validadeCert;
    }

}