<?php
namespace Util;

use Zeedhi\Framework\Session\Session;
use Util\DateUtil;

class Environment {

	/** @var \DateTime(); */
	protected $currentTime;
    /** @var Session */
	protected $session;
	
	const PF_SERVICE_NAME = 'PF';
	const PG_SERVICE_NAME = 'PG';

	public function __construct(Session $session) {
		$this->currentTime = new \DateTime();
		$this->session = $session;
	}

    /**
     * @return string
     */
    public function getCdFilial() {
        return $this->session->get("CDFILIAL");
    }

    /**
     * @param string $cdFilial
     */
    public function setCdFilial($cdFilial)
    {
        $this->session->set("CDFILIAL", $cdFilial);
    }

    /**
     * @return string
     */
    public function getCdOperador()
    {
        return $this->session->get("CDOPERADOR");
    }

    /**
     * @param string $cdOperador
     */
    public function setCdOperador($cdOperador)
    {
        $this->session->set("CDOPERADOR", $cdOperador);
    }

    /**
     * @return string
     */
    public function getNmOperador()
    {
        return $this->session->get("NMOPERADOR");
    }

    /**
     * @param string $nmOperador
     */
    public function setNmOperador($nmOperador)
    {
        $this->session->set("NMOPERADOR", $nmOperador);
    }

    /**
     * @return string
     */
    public function getNrEstrutTrab() {
        return $this->session->get("NRESTRUTTRAB");
    }

    /**
     * @param string $nrEstrutTrab
     */
    public function setNrEstrutTrab($nrEstrutTrab) {
        $this->session->set("NRESTRUTTRAB", $nrEstrutTrab);
    }

    /**
     * @return string
     */
    public function getNrOrgPadrao()
    {
        return $this->session->get("NRORGPADRAO");
    }

    /**
     * @param string $nrOrgPadrao
     */
    public function setNrOrgPadrao($nrOrgPadrao)
    {
        $this->session->set("NRORGPADRAO", $nrOrgPadrao);
    }

    /**
     * @return string
     */
    public function getNrOrgTrab()
    {
        return $this->session->get("NRORGTRAB");
    }

    /**
     * @param string $nrOrgTrab
     */
    public function setNrOrgTrab($nrOrgTrab)
    {
        $this->session->set("NRORGTRAB", $nrOrgTrab);
    }

    /**
     * @return string
     */
    public function getNrOrg()
    {
        return $this->session->get("NRORG");
    }

    /**
     * @param string $nrOrgTrab
     */
    public function setNrOrg($nrOrg)
    {
        $this->session->set("NRORG", $nrOrg);
    }

    /**
     * @return string
     */
    public function getNmestruturam()
    {
        return $this->session->get("NMESTRUTURAM");
    }

    /**
     * @param string $nmestruturam
     */
    public function setNmestruturam($nmestruturam)
    {
        $this->session->set("NMESTRUTURAM", $nmestruturam);
    }

    /**
     * @return string
     */
    public function getNrvinculom()
    {
        return $this->session->get("NRVINCULOM");
    }

    /**
     * @param string $nrvinculom
     */
    public function setNrvinculom($nrvinculom)
    {
        $this->session->set("NRVINCULOM", $nrvinculom);
    }
	
	public function getCurrentTime() {
		return $this->currentTime;
	}
	
	/**
     * @param string $dtmescomptencdiacorrente
     */
	public function getDtmescomptencDiaCorrente() {
        return DateUtil::getPrimeiroDiaDoMes(DateUtil::getDataAtual())->format(DateUtil::FORMATO_BRASILEIRO);
    }
    
    /**
     * @return string
     */
    public function getDtCompetencia() {
        $value = $this->session->get('dtmescompetenc');
        return $value; 
    }

    /**
     * @param string $dtcompetencia
     */
    public function setDtCompetencia($dtcompetencia)
    {
        $this->session->set("dtmescompetenc", $dtcompetencia);
    }
    
    /**
     * @param string $ultimoDiaMesCorrente
     */
    public function getUltimoDiaMesCorrente() {
        return DateUtil::getUltimoDiaDoMes(DateUtil::getDataDeString($this->getDtmescomptencDiaCorrente()))->format(DateUtil::FORMATO_BRASILEIRO);
    }
    
    /**
     * @return string
     */
    public function getRequestOriginService() {
        return $this->session->get("ORIGINSERVICE");
    }
    
    /**
     * @return bool
     */
    public function isRequestFromPortalFuncionario() {
        return $this->getRequestOriginService() == self::PF_SERVICE_NAME;
    }
    
    /**
     * @return bool
     */
    public function isRequestFromPortalGestor() {
        return $this->getRequestOriginService() == self::PG_SERVICE_NAME;
    }
    
    /*-------------------------------------------------------------------------*/

    public function getTipoEstruturaLegalOrg() {
        $value = $this->session->get('nrtipoestrutlegal');
        if(!$value){
            $organizacao = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::GPE_PARAMORG)->findOneBy(array('nrorg' => $this->getNrOrgTrab()));
            if (is_object($organizacao)) {
                $this->session->set("nrtipoestrutlegal", $organizacao->getNrtpestrutlegal());
                $value = $organizacao->getNrtpestrutlegal();
            }
        }
        return $value;
    }

    public function getTipoEstruturaGerencialOrg() {
        $value = $this->session->get('nrtipoestrutgeren');
        if(!$value){
            $organizacao = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::GPE_PARAMORG)->findOneBy(array('nrorg' => $this->getNrOrgTrab()));
            if (is_object($organizacao)) {
                $this->session->set("nrtipoestrutgeren", $organizacao->getNrtpestrutgeren());
                $value = $organizacao->getNrtpestrutgeren();
            }
        }
        return $value;
    }
    
    public function getTipoEstruturaTomadorOrg() {
        $value = $this->session->get('nrtipoestrutomador');
        if(!$value){
            $organizacao = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::GPE_PARAMORG)->findOneBy(array('nrorg' => $this->getNrOrgTrab()));
            if (is_object($organizacao)) {
                $this->session->set("nrtipoestrutomador", $organizacao->getNrtpestrutomador());
                $value = $organizacao->getNrtpestrutomador();
            }
        }
        return !$value ? '7' : $value;
    }
    
    /*-------------------------------------------------------------------------*/
    
    public function getEsoIniValidCadIniProducao() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_INIVALID_PRODUCAO');
        if (empty($result)) {
            return '01/07/2018';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidNaoPerProducao() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_ININPERI_PRODUCAO');
        if (empty($result)) {
            return '01/10/2018';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidPeriodProducao() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_INIPERIO_PRODUCAO');
        if (empty($result)) {
            return '01/11/2018';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidCadIniProdRest() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_INIVALID_PRODREST');
        if (empty($result)) {
            return '01/01/2017';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidNaoPerProdRest() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_ININPERI_PRODREST');
        if (empty($result)) {
            return '01/03/2017';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidPeriodProdRest() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_INIPERIO_PRODREST');
        if (empty($result)) {
            return '01/05/2017';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidCadIniNacioSimples() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_INIVALID_NACIOSIMPLES');
        if (empty($result)) {
            return '10/01/2019';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidNaoPerNacioSimples() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_ININPERI_NACIOSIMPLES');
        if (empty($result)) {
            return '10/04/2019';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
    
    public function getEsoIniValidPeriodNacioSimples() {
        $result = \Setforms2\Shared\Registry::getEntityManager()->getRepository(Repositories::FPA_VALORREFERENCIAM)->
            retornaValorReferencia($this->getNrOrgTrab(), $this->getNrorgPadrao(), $this->getDtCompetencia(), 'ESOCIAL_INIPERIO_NACIOSIMPLES');
        if (empty($result)) {
            return '10/06/2019';
        } else {
            return $result[0]->getDtinivigencia()->format('d/m/Y');
        }
    }
}